@@ -39,9 +39,17 @@ import json
 import datetime
 
 __name__ = 'BenBotAsync'
-__version__ = '2.3.1'
+__version__ = '2.4.1'
 __author__ = 'xMistt'
 
+try:
+    import fortnitepy
+
+    if fortnitepy.__version__ == '1.7.1':
+        raise ValueError('Please update your fortnitepy to 2.0.0+.')
+except ImportError:
+    pass
+
 BEN_BOT_BASE = 'https://benbotfn.tk/api/v1'
 
 IOS_TOKEN_TEMPLATE = (b'SnJ5cGJ6ciAlZiwgVid6IG4geWJvb2wgb2JnIHpucXIgb2wga1p2ZmdnL3p2Zmdr'
@@ -53,6 +61,7 @@ IOS_TOKEN_TEMPLATE = (b'SnJ5cGJ6ciAlZiwgVid6IG4geWJvb2wgb2JnIHpucXIgb2wga1p2Zmdn
 def time() -> str:
     return datetime.datetime.now().strftime('%H:%M:%S')
 
+
 # Credit to Terbau for this function.
 async def json_or_text(response: aiohttp.ClientResponse) -> Union[str, dict]:
     text = await response.text(encoding='utf-8')
@@ -64,7 +73,7 @@ async def json_or_text(response: aiohttp.ClientResponse) -> Union[str, dict]:
 async def set_default_loadout(client: fortnitepy.Client, config: dict, member: fortnitepy.PartyMember) -> None:
     """Function which can be used with fortnitepy to set the default loadout."""
 
-    party_update_meta = client.party if client.party else client.user.party  # Saves direct route to the party_update_meta object.
+    party_update_meta = client.party  # Saves direct route to the party_update_meta object.
     kairos_profile = member.display_name  # Used to generated iOS token required for mass cosmetic updates.
 
     unique_ios_token = codecs.decode(
@@ -78,31 +87,38 @@ async def set_default_loadout(client: fortnitepy.Client, config: dict, member: f
         unique_ios_token
     )
 
-    await party_update_meta.me.edit_and_keep(  # Sets default loadout.
-        functools.partial(
-            party_update_meta.me.set_outfit,
-            config['cid']
-        ),
-        functools.partial(
-            party_update_meta.me.set_backpack,
-            config['bid']
-        ),
-        functools.partial(
-            party_update_meta.me.set_banner,
-            icon=config['banner'],
-            color=config['banner_colour'],
-            season_level=config['level']
-        ),
-        functools.partial(
-            party_update_meta.me.set_battlepass_info,
-            has_purchased=True,
-            level=config['bp_tier']
+    if (party_update_meta.id == client.party.id
+            and client.default_party_member_config.cls is not fortnitepy.party.JustChattingClientPartyMember):
+        await party_update_meta.me.edit_and_keep(  # Sets default loadout.
+            functools.partial(
+                party_update_meta.me.set_outfit,
+                config['cid']
+            ),
+            functools.partial(
+                party_update_meta.me.set_backpack,
+                config['bid']
+            ),
+            functools.partial(
+                party_update_meta.me.set_pickaxe,
+                config['pickaxe_id']
+            ),
+            functools.partial(
+                party_update_meta.me.set_banner,
+                icon=config['banner'],
+                color=config['banner_colour'],
+                season_level=config['level']
+            ),
+            functools.partial(
+                party_update_meta.me.set_battlepass_info,
+                has_purchased=True,
+                level=config['bp_tier']
+            )
         )
-    )
 
     await asyncio.sleep(1)  # Waits 1 second after submitting iOS token before emoting to avoid rate limits.
 
-    if party_update_meta.id == client.user.party.id:
+    if (party_update_meta.id == client.party.id
+            and client.default_party_member_config.cls is not fortnitepy.party.JustChattingClientPartyMember):
         await party_update_meta.me.clear_emote()  # Clears emote to allow the next emote to play.
         await party_update_meta.me.set_emote(asset=config['eid'])  # Plays the emote from config.
 
@@ -267,4 +283,3 @@ async def get_cosmetic_from_id(cosmetic_id: str) -> BRCosmetic:
                 raise NotFound('Invalid ID.')
 
             return BRCosmetic(data)
-
